<?php
/**
 * Theme Metabox Options
 * @package gana
 * @since 1.0.0
 */

if (!defined('ABSPATH')) {
    exit(); // exit if access directly
}

if (class_exists('CSF')) {

    $allowed_html = gana()->kses_allowed_html(array('mark'));

    $prefix = 'gana';

    /*-------------------------------------
        Post Format Options
    -------------------------------------*/
    CSF::createMetabox($prefix . '_post_video_options', array(
        'title' => esc_html__('Video Post Format Options', 'gana'),
        'post_type' => 'post',
        'post_formats' => 'video'
    ));
    CSF::createSection($prefix . '_post_video_options', array(
        'fields' => array(
            array(
                'id' => 'video_url',
                'type' => 'text',
                'title' => esc_html__('Enter Video URL', 'gana'),
                'desc' => wp_kses(__('enter <mark>video url</mark> to show in frontend', 'gana'), $allowed_html)
            )
        )
    ));
    CSF::createMetabox($prefix . '_post_gallery_options', array(
        'title' => esc_html__('Gallery Post Format Options', 'gana'),
        'post_type' => 'post',
        'post_formats' => 'gallery'
    ));
    CSF::createSection($prefix . '_post_gallery_options', array(
        'fields' => array(
            array(
                'id' => 'gallery_images',
                'type' => 'gallery',
                'title' => esc_html__('Select Gallery Photos', 'gana'),
                'desc' => wp_kses(__('select <mark>gallery photos</mark> to show in frontend', 'gana'), $allowed_html)
            )
        )
    ));

    /*-------------------------------------
      Page Container Options
    -------------------------------------*/
    CSF::createMetabox($prefix . '_page_container_options', array(
        'title' => esc_html__('Page Options', 'gana'),
        'post_type' => array('page'),
    ));
    CSF::createSection($prefix . '_page_container_options', array(
        'title' => esc_html__('Layout & Colors', 'gana'),
        'icon' => 'fa fa-columns',
        'fields' => Gana_Group_Fields::page_layout()
    ));
    CSF::createSection($prefix . '_page_container_options', array(
        'title' => esc_html__('Header Footer & Breadcrumb', 'gana'),
        'icon' => 'fa fa-header',
        'fields' => Gana_Group_Fields::Page_Container_Options('header_options')
    ));
    CSF::createSection($prefix . '_page_container_options', array(
        'title' => esc_html__('Width & Padding', 'gana'),
        'icon' => 'fa fa-file-o',
        'fields' => Gana_Group_Fields::Page_Container_Options('container_options')
    ));
    //	Service Meta Box
    CSF::createMetabox($prefix . '_service_options', array(
        'title' => esc_html__('Service Options', 'gana'),
        'post_type' => 'service',
    ));
    CSF::createSection($prefix . '_service_options', array(
        'fields' => array(
            array(
                'id' => 'service_icon',
                'type' => 'media',
                'title' => esc_html__('Icon', 'gana'),
                'desc' => wp_kses(__('Select Your Icon', 'gana'), $allowed_html)
            ),
            array(
                'id' => 'service_content',
                'type' => 'textarea',
                'title' => esc_html__('service content', 'gana'),
                'desc' => wp_kses(__('Select Your service content', 'gana'), $allowed_html)
            )
        )
    ));

    /*-------------------------------------
     Team Options
    -------------------------------------*/
    CSF::createMetabox($prefix . '_team_options', array(
        'title' => esc_html__('Team Options', 'gana'),
        'post_type' => array('team'),
        'priority' => 'high'
    ));
    CSF::createSection($prefix . '_team_options', array(
        'title' => esc_html__('Team Icon', 'gana'),
        'id' => 'gana-team-icon',
        'fields' => array(
            array(
                'id' => 'team_icon',
                'type' => 'icon',
                'desc' => wp_kses(__('Select Your Icon', 'gana'), $allowed_html)
            )
        )
    ));
    CSF::createSection($prefix . '_team_options', array(
        'title' => esc_html__('Team Info', 'gana'),
        'id' => 'gana-info',
        'fields' => array(
            array(
                'id' => 'designation',
                'type' => 'text',
                'title' => esc_html__('Designation', 'gana'),
            ),
            array(
                'id' => 'description',
                'type' => 'textarea',
                'title' => esc_html__('Description', 'gana'),
            ),
            array(
                'id' => 'description_2',
                'type' => 'textarea',
                'title' => esc_html__('Description Two', 'gana'),
            ),
            array(
                'id' => 'phone',
                'type' => 'text',
                'title' => esc_html__('phone', 'gana'),
            ),
            array(
                'id' => 'email',
                'type' => 'text',
                'title' => esc_html__('email', 'gana'),
            ),
            array(
                'id' => 'team-skill',
                'type' => 'repeater',
                'title' => esc_html__('Team Skill', 'gana'),
                'fields' => array(

                    array(
                        'id' => 'title',
                        'type' => 'text',
                        'title' => esc_html__('Title', 'gana')
                    ),
                    array(
                        'id' => 'count_val',
                        'type' => 'text',
                        'title' => esc_html__('Count Value', 'gana')
                    ),

                ),
            ),
        )
    ));
    CSF::createSection($prefix . '_team_options', array(
        'title' => esc_html__('Social Info', 'gana'),
        'id' => 'social-info',
        'fields' => array(
            array(
                'id' => 'social-icons',
                'type' => 'repeater',
                'title' => esc_html__('Social Info', 'gana'),
                'fields' => array(

                    array(
                        'id' => 'title',
                        'type' => 'text',
                        'title' => esc_html__('Title', 'gana')
                    ),
                    array(
                        'id' => 'icon',
                        'type' => 'icon',
                        'title' => esc_html__('Icon', 'gana')
                    ),
                    array(
                        'id' => 'url',
                        'type' => 'text',
                        'title' => esc_html__('URL', 'gana')
                    ),

                ),
            ),
        )
    ));

    //	Project Meta Box
    CSF::createMetabox($prefix . '_project_options', array(
        'title' => esc_html__('Project Options', 'gana'),
        'post_type' => 'project',
    ));

    CSF::createSection($prefix . '_project_options', array(
        'fields' => array(
            array(
                'id' => 'project_meta',
                'type' => 'text',
                'title' => esc_html__('Project Meta', 'gana'),
                'default' => esc_html__('Las vegas ', 'gana'),
            ),
            array(
                'id' => 'project_clients',
                'type' => 'text',
                'title' => esc_html__('Project Clients', 'gana'),
                'default' => esc_html__('Porter Victoria ', 'gana'),
            ),
            array(
                'id' => 'project_cat',
                'type' => 'text',
                'title' => esc_html__('Category', 'gana'),
                'default' => esc_html__('It Service ', 'gana'),
            ),
            array(
                'id' => 'project_date',
                'type' => 'text',
                'title' => esc_html__('Project Date', 'gana'),
                'default' => esc_html__('20 January, 2023 ', 'gana'),
            ),
            array(
                'id' => 'project_location',
                'type' => 'text',
                'title' => esc_html__('Project Location', 'gana'),
                'default' => esc_html__('Cakung, Jakarta ', 'gana'),
            )
        )
    ));

    //	Product Meta Box
    CSF::createMetabox($prefix . '_product_options', array(
        'title' => esc_html__('Product Options', 'gana'),
        'post_type' => 'product',
    ));
    CSF::createSection($prefix . '_product_options', array(
        'fields' => array(
            array(
                'id' => 'product_audio_img',
                'type' => 'media',
                'title' => esc_html__('Product audio image', 'gana'),
            ),
            array(
                'id' => 'product_audio_list',
                'type' => 'text',
                'title' => esc_html__('Product audio url', 'gana'),
                'default' => esc_html__('http://physical-authority.surge.sh/music/2.mp3', 'gana'),
            ),
            array(
                'id' => 'product_subtitle',
                'type' => 'text',
                'title' => esc_html__('Product Subtitle', 'gana'),
                'default' => esc_html__('Ray studio', 'gana'),
            ),
            array(
                'id' => 'download_text',
                'type' => 'text',
                'title' => esc_html__('download text', 'gana'),
                'default' => esc_html__('Download: 2.4K', 'gana'),
            ),
        )
    ));

    //	Courses Meta Box
    CSF::createMetabox($prefix . '_courses_options', array(
        'title' => esc_html__('Courses Options', 'gana'),
        'post_type' => 'courses',
    ));

    CSF::createSection($prefix . '_courses_options', array(
        'title' => esc_html__('Social Info', 'gana'),
        'id' => 'social-info',
        'fields' => array(
            array(
                'id' => 'course_start_date_option',
                'type' => 'text',
                'title' => esc_html__('Start From', 'gana'),
                'default' => esc_html__('Thursday, Nov 4, 2023', 'gana'),
            ),
            array(
                'id' => 'study-option',
                'type' => 'repeater',
                'title' => esc_html__('Study Options', 'gana'),
                'fields' => array(

                    array(
                        'id' => 'qualification',
                        'type' => 'text',
                        'title' => esc_html__('Qualification', 'gana'),
                        'default' => esc_html__('Bachelor of Aviation (Hons)', 'gana'),
                    ),
                    array(
                        'id' => 'length',
                        'type' => 'text',
                        'title' => esc_html__('Length', 'gana'),
                        'default' => esc_html__('9 months full time', 'gana'),
                    ),
                    array(
                        'id' => 'code',
                        'type' => 'text',
                        'title' => esc_html__('Code', 'gana'),
                        'default' => esc_html__('ba1x', 'gana'),
                    ),
                ),
            ),
            array(
                'id' => 'course_module_option',
                'type' => 'text',
                'title' => esc_html__('Course Module Title', 'gana'),
                'default' => esc_html__('Download full course Module', 'gana'),
            ),
            array(
                'id' => 'course_module_button_title',
                'type' => 'text',
                'title' => esc_html__('Course Module Button Title', 'gana'),
                'default' => esc_html__('Download', 'gana'),
            ),
            array(
                'id' => 'course_module_button_url',
                'type' => 'text',
                'title' => esc_html__('Course Module Button URL', 'gana'),
                'default' => esc_html__('#', 'gana'),
            ),
        )
    ));
}//endif