<?php
/**
 * Theme Options
 * @package gana
 * @since 1.0.0
 */

if (!defined('ABSPATH')) {
    exit(); // exit if access directly
}
// Control core classes for avoid errors
if (class_exists('CSF')) {

    $allowed_html = gana()->kses_allowed_html(array('mark'));
    $prefix = 'gana';
    // Create options
    CSF::createOptions($prefix . '_theme_options', array(
        'menu_title' => esc_html__('Theme Options', 'gana'),
        'menu_slug' => 'gana_theme_options',
        'menu_parent' => 'gana_theme_options',
        'menu_type' => 'submenu',
        'footer_credit' => ' ',
        'menu_icon' => 'fa fa-filter',
        'show_footer' => false,
        'enqueue_webfont' => false,
        'show_search' => true,
        'show_reset_all' => true,
        'show_reset_section' => true,
        'show_all_options' => false,
        'theme' => 'dark',
        'framework_title' => gana()->get_theme_info('name')
    ));

    /*-------------------------------------------------------
        ** General  Options
    --------------------------------------------------------*/
    CSF::createSection($prefix . '_theme_options', array(
        'title' => esc_html__('General', 'gana'),
        'id' => 'general_options',
        'icon' => 'fas fa-cogs',
    ));
    /* Preloader */
    CSF::createSection($prefix . '_theme_options', array(
        'title' => esc_html__('Preloader & SVG Enable', 'gana'),
        'id' => 'theme_general_preloader_options',
        'icon' => 'fa fa-spinner',
        'parent' => 'general_options',
        'fields' => array(
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Preloader Options', 'gana') . '</h3>'
            ),
            array(
                'id' => 'preloader_enable',
                'title' => esc_html__('Preloader', 'gana'),
                'type' => 'switcher',
                'desc' => wp_kses(__('you can set <mark>Yes / No</mark> to enable/disable preloader', 'gana'), $allowed_html),
                'default' => true,
            ),
            array(
                'id' => 'preloader_bg_color',
                'title' => esc_html__('Preloader Background Color', 'gana'),
                'type' => 'color',
                'default' => '',
                'desc' => wp_kses(__('you can set <mark>overlay color</mark> for preloader background image', 'gana'), $allowed_html),
                'dependency' => array('preloader_enable', '==', 'true')
            ),
            array(
                'id' => 'header_sticky_enable',
                'title' => esc_html__('Header Sticky', 'gana'),
                'type' => 'switcher',
                'desc' => wp_kses(__('you can set <mark>Yes / No</mark> to enable/disable Header', 'gana'), $allowed_html),
                'default' => true,
            ),
            array(
                'id' => 'enable_svg_upload',
                'type' => 'switcher',
                'title' => esc_html__('Enable Svg Upload ?', 'gana'),
                'desc' => esc_html__('If you want to enable or disable svg upload you can set ( YES / NO )', 'gana'),
                'default' => false,
            ),
        )
    ));

    /*-------------------------------------------------------
           ** Typography  Options
    --------------------------------------------------------*/
    CSF::createSection($prefix . '_theme_options', array(
        'id' => 'typography',
        'title' => esc_html__('Typography', 'gana'),
        'icon' => 'fas fa-text-height',
        'parent' => 'general_options',
        'fields' => array(
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Body Font Options', 'gana') . '</h3>',
            ),
            array(
                'type' => 'typography',
                'title' => esc_html__('Typography', 'gana'),
                'id' => '_body_font',
                'default' => array(
                    'font-family' => 'Inter',
                    'font-size' => '16',
                    'line-height' => '26',
                    'unit' => 'px',
                    'type' => 'google',
                ),
                'color' => false,
                'subset' => false,
                'text_align' => false,
                'text_transform' => false,
                'letter_spacing' => false,
                'line_height' => false,
                'desc' => wp_kses(__('you can set <mark>font</mark> for all html tags (if not use different heading font)', 'gana'), $allowed_html),
            ),
            array(
                'id' => 'body_font_variant',
                'type' => 'select',
                'title' => esc_html__('Load Font Variant', 'gana'),
                'multiple' => true,
                'chosen' => true,
                'options' => array(
                    '300' => esc_html__('Light 300', 'gana'),
                    '400' => esc_html__('Regular 400', 'gana'),
                    '500' => esc_html__('Medium 500', 'gana'),
                    '600' => esc_html__('Semi Bold 600', 'gana'),
                    '700' => esc_html__('Bold 700', 'gana'),
                    '800' => esc_html__('Extra Bold 800', 'gana'),
                ),
                'default' => array('400', '500', '600', '700')
            ),
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Heading Font Options', 'gana') . '</h3>',
            ),
            array(
                'type' => 'switcher',
                'id' => 'heading_font_enable',
                'title' => esc_html__('Heading Font', 'gana'),
                'desc' => wp_kses(__('you can set <mark>yes</mark> to select different heading font', 'gana'), $allowed_html),
                'default' => true
            ),
            array(
                'type' => 'typography',
                'title' => esc_html__('Typography', 'gana'),
                'id' => 'heading_font',
                'default' => array(
                    'font-family' => 'Inter',
                    'type' => 'google',
                ),
                'color' => false,
                'subset' => false,
                'text_align' => false,
                'text_transform' => false,
                'letter_spacing' => false,
                'font_size' => false,
                'line_height' => false,
                'desc' => wp_kses(__('you can set <mark>font</mark> for  for heading tag .eg: h1,h2mh3,h4,h5,h6', 'gana'), $allowed_html),
                'dependency' => array('heading_font_enable', '==', 'true')
            ),
            array(
                'id' => 'heading_font_variant',
                'type' => 'select',
                'title' => esc_html__('Load Font Variant', 'gana'),
                'multiple' => true,
                'chosen' => true,
                'options' => array(
                    '300' => esc_html__('Light 300', 'gana'),
                    '400' => esc_html__('Regular 400', 'gana'),
                    '500' => esc_html__('Medium 500', 'gana'),
                    '600' => esc_html__('Semi Bold 600', 'gana'),
                    '700' => esc_html__('Bold 700', 'gana'),
                    '800' => esc_html__('Extra Bold 800', 'gana'),
                ),
                'default' => array('400', '500', '600', '700'),
                'dependency' => array('heading_font_enable', '==', 'true')
            ),
        )
    ));

    /* Preloader */
    CSF::createSection($prefix . '_theme_options', array(
        'title' => esc_html__('Back To Top', 'gana'),
        'id' => 'theme_general_back_top_options',
        'icon' => 'fa fa-arrow-up',
        'parent' => 'general_options',
        'fields' => array(
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Back Top Options', 'gana') . '</h3>'
            ),
            array(
                'id' => 'back_top_enable',
                'title' => esc_html__('Back Top', 'gana'),
                'type' => 'switcher',
                'desc' => wp_kses(__('you can set <mark>Yes / No</mark> to show/hide back to top', 'gana'), $allowed_html),
                'default' => true,
            ),
            array(
                'id' => 'back_top_icon',
                'title' => esc_html__('Back Top Icon', 'gana'),
                'type' => 'icon',
                'default' => 'fa fa-angle-up',
                'desc' => wp_kses(__('you can set <mark>icon</mark> for back to top.', 'gana'), $allowed_html),
                'dependency' => array('back_top_enable', '==', 'true')
            ),
        )
    ));

    /* Preloader */
    CSF::createSection($prefix . '_theme_options', array(
        'title' => esc_html__('sitebar', 'gana'),
        'id' => 'theme_general_sitebar_options',
        'icon' => 'fa fa-arrow-up',
        'parent' => 'general_options',
        'fields' => array(
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Sitebar Option', 'gana') . '</h3>'
            ),
            array(
                'id' => 'sitebar_logo',
                'type' => 'media',
                'title' => esc_html__('Sitebar Logo', 'gana'),
                'library' => 'image',
                'desc' => wp_kses(__('you can upload <mark> logo</mark> here it will overwrite customizer uploaded logo', 'gana'), $allowed_html),
            ),
            array(
                'id' => 'sitebar_content_1',
                'type' => 'text',
                'title' => esc_html__('Sitebar content', 'gana'),
                'default' => esc_html__('We understand better that enim ad minim veniam, consectetur adipis cing elit, sed do', 'gana'),
            ),
            array(
                'id' => 'sitebar_content_2',
                'type' => 'text',
                'title' => esc_html__('Sitebar content', 'gana'),
                'default' => esc_html__('We understand better that enim ad minim veniam, consectetur adipi scing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.', 'gana'),
            ),
            array(
                'id' => 'sitebar_address',
                'type' => 'text',
                'title' => esc_html__('Sitebar Address', 'gana'),
                'default' => esc_html__('Lavaca Street, Suite 2000', 'gana'),
            ),
            array(
                'id' => 'sitebar_email',
                'type' => 'text',
                'title' => esc_html__('Sitebar email', 'gana'),
                'default' => esc_html__('email@evha.com', 'gana'),
            ),
            array(
                'id' => 'sitebar_phone',
                'type' => 'text',
                'title' => esc_html__('Sitebar phone', 'gana'),
                'default' => esc_html__('(+880) 172570051', 'gana'),
            ),
            array(
                'id' => 'sitebar_facebook',
                'type' => 'text',
                'title' => esc_html__('Sitebar facebook url', 'gana'),
                'default' => esc_html__('#', 'gana'),
            ),
            array(
                'id' => 'sitebar_twitter',
                'type' => 'text',
                'title' => esc_html__('Sitebar twitter url', 'gana'),
                'default' => esc_html__('#', 'gana'),
            ),
            array(
                'id' => 'sitebar_instagram',
                'type' => 'text',
                'title' => esc_html__('Sitebar instagram', 'gana'),
                'default' => esc_html__('#', 'gana'),
            ),
            array(
                'id' => 'sitebar_linkedin',
                'type' => 'text',
                'title' => esc_html__('Sitebar linkedin', 'gana'),
                'default' => esc_html__('#', 'gana'),
            ),
        )
    ));

    /*----------------------------------
        Header & Footer Style
    -----------------------------------*/
    CSF::createSection($prefix . '_theme_options', array(
        'title' => esc_html__('Set Header & Footer Type', 'gana'),
        'id' => 'header_footer_style_options',
        'icon' => 'eicon-banner',
        'fields' => array(
            array(
                'type' => 'subheading',
                'content' => esc_html__('Global Header Style', 'gana'),
            ),
            array(
                'id' => 'navbar_type',
                'title' => esc_html__('Navbar Type', 'gana'),
                'type' => 'image_select',
                'options' => array(
                    '' => GANA_THEME_SETTINGS_IMAGES . '/header/01.png',
                    'style-01' => GANA_THEME_SETTINGS_IMAGES . '/header/02.png'
                ),
                'default' => '',
                'desc' => wp_kses(__('you can set <mark>navbar type</mark> it will show in every page except you select specific navbar type form page settings.', 'gana'), $allowed_html),
            ),
            array(
                'type' => 'subheading',
                'content' => esc_html__('Global Footer Style', 'gana'),
            ),
            array(
                'id' => 'footer_type',
                'title' => esc_html__('Footer Type', 'gana'),
                'type' => 'image_select',
                'options' => array(
                    '' => GANA_THEME_SETTINGS_IMAGES . '/footer/01.png',
                    'style-01' => GANA_THEME_SETTINGS_IMAGES . '/footer/02.png'
                ),
                'default' => '',
                'desc' => wp_kses(__('you can set <mark>footer type</mark> it will show in every page except you select specific navbar type form page settings.', 'gana'), $allowed_html),
            ),
        )
    ));

    /*-------------------------------------------------------
       ** Entire Site Header  Options
   --------------------------------------------------------*/
    CSF::createSection($prefix . '_theme_options', array(
        'id' => 'headers_settings',
        'title' => esc_html__('Headers', 'gana'),
        'icon' => 'fa fa-home'
    ));
    /* Header Style 01 */
    CSF::createSection($prefix . '_theme_options', array(
        'title' => esc_html__('Header One', 'gana'),
        'id' => 'theme_header_one_options',
        'icon' => 'fa fa-image',
        'parent' => 'headers_settings',
        'fields' => array(
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Logo Options', 'gana') . '</h3>'
            ),
            array(
                'id' => 'header_one_logo',
                'type' => 'media',
                'title' => esc_html__('Logo', 'gana'),
                'library' => 'image',
                'desc' => wp_kses(__('you can upload <mark> logo</mark> here it will overwrite customizer uploaded logo', 'gana'), $allowed_html),
            ),
            array(
                'id' => 'header_one_logo_two',
                'type' => 'media',
                'title' => esc_html__('Logo Two', 'gana'),
                'library' => 'image',
                'desc' => wp_kses(__('you can upload <mark> logo</mark> here it will overwrite customizer uploaded logo', 'gana'), $allowed_html),
            ),
            array(
                'id' => 'header_right_btn_text',
                'type' => 'text',
                'title' => esc_html__('Right Btn text', 'gana'),
                'default' => 'Join Free',
            ),
            array(
                'id' => 'header_right_btn_url',
                'type' => 'text',
                'title' => esc_html__('Right Btn url', 'gana'),
                'default' => esc_html__('#', 'gana'),
            ),
            array(
                'id' => 'header_navbar_button',
                'type' => 'switcher',
                'title' => esc_html__('Info Button', 'gana'),
                'default' => true,
                'desc' => wp_kses(__('you can <mark> show/hide</mark> navbar button of header two', 'gana'), $allowed_html),
            ),
        )
    ));

    /* Header Style 02 */
    CSF::createSection($prefix . '_theme_options', array(
        'title' => esc_html__('Header Two', 'gana'),
        'id' => 'theme_header_two_options',
        'icon' => 'fa fa-image',
        'parent' => 'headers_settings',
        'fields' => array(
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Navbar Options', 'gana') . '</h3>'
            ),
            array(
                'id' => 'header_two_search_item',
                'type' => 'switcher',
                'title' => esc_html__('Search on/off Button', 'gana'),
                'default' => true,
                'desc' => wp_kses(__('you can <mark> show/hide</mark> info item of header five', 'gana'), $allowed_html),
            ),
            array(
                'id' => 'header_two_logo',
                'type' => 'media',
                'title' => esc_html__('Logo', 'gana'),
                'library' => 'image',
                'desc' => wp_kses(__('you can upload <mark> logo</mark> here it will overwrite customizer uploaded logo', 'gana'), $allowed_html),
            ),
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Project Options', 'gana') . '</h3>'
            ),
            array(
                'id' => 'header_two_training_title',
                'type' => 'text',
                'title' => esc_html__('Project Title', 'gana'),
                'default' => esc_html__('Project', 'gana')
            ),
            array(
                'id' => 'header_two_training_url',
                'type' => 'text',
                'title' => esc_html__('Project URL', 'gana'),
                'default' => '#'
            ),
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Info Bar Options', 'gana') . '</h3>'
            ),
            array(
                'id' => 'header_two_info_item',
                'type' => 'switcher',
                'title' => esc_html__('Info Item Button', 'gana'),
                'default' => true,
                'desc' => wp_kses(__('you can <mark> show/hide</mark> info item of header five', 'gana'), $allowed_html),
            ),
            array(
                'id' => 'header_two_info_item_repeater',
                'type' => 'repeater',
                'title' => esc_html__('Info Item Repeater', 'gana'),
                'dependency' => array('header_two_info_item', '==', 'true'),
                'fields' => array(
                    array(
                        'id' => 'header_two_info_item_title',
                        'type' => 'text',
                        'title' => esc_html__('Info  Title', 'gana'),
                        'default' => esc_html__('Call Us Free', 'gana')
                    ),
                    array(
                        'id' => 'header_two_info_item_number',
                        'type' => 'text',
                        'title' => esc_html__('Info Number', 'gana'),
                        'default' => esc_html__('+91 458 654 528', 'gana')
                    ),
                    array(
                        'id' => 'header_two_info_item_url',
                        'type' => 'text',
                        'title' => esc_html__('Info URL', 'gana'),
                        'default' => '#'
                    ),
                )
            ),
            array(
                'id' => 'header_two_navbar_button',
                'type' => 'switcher',
                'title' => esc_html__('Info Button', 'gana'),
                'default' => true,
                'desc' => wp_kses(__('you can <mark> show/hide</mark> navbar button of header two', 'gana'), $allowed_html),
            ),
            array(
                'id' => 'header_two_navbar_title',
                'type' => 'text',
                'title' => esc_html__('Button Title', 'gana'),
                'default' => esc_html__('Request Quote', 'gana'),
                'dependency' => array('header_two_navbar_button', '==', 'true')
            ),
            array(
                'id' => 'header_two_navbar_url',
                'type' => 'text',
                'title' => esc_html__('Button URL', 'gana'),
                'default' => '#',
                'dependency' => array('header_two_navbar_button', '==', 'true')
            ),
        )
    ));

    /* Header Style 03 */
    CSF::createSection($prefix . '_theme_options', array(
        'title' => esc_html__('Header Three', 'gana'),
        'id' => 'theme_header_three_options',
        'icon' => 'fa fa-image',
        'parent' => 'headers_settings',
        'fields' => array(
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Navbar Options', 'gana') . '</h3>'
            ),
            array(
                'id' => 'header_three_logo',
                'type' => 'media',
                'title' => esc_html__('Logo', 'gana'),
                'library' => 'image',
                'desc' => wp_kses(__('you can upload <mark> logo</mark> here it will overwrite customizer uploaded logo', 'gana'), $allowed_html),
            ),
            array(
                'id' => 'header_three_search_item',
                'type' => 'switcher',
                'title' => esc_html__('Search on/off Button', 'gana'),
                'default' => true,
                'desc' => wp_kses(__('you can <mark> show/hide</mark> info item of header three', 'gana'), $allowed_html),
            ),
            array(
                'id' => 'header_three_dark_light_item',
                'type' => 'switcher',
                'title' => esc_html__('Dark Light on/off Button', 'gana'),
                'default' => true,
                'desc' => wp_kses(__('you can <mark> show/hide</mark> info item of header three', 'gana'), $allowed_html),
            ),
            array(
                'id' => 'header_three_btn_1_text',
                'type' => 'text',
                'title' => esc_html__('Nav 1 Text', 'gana'),
                'default' => esc_html__('Best Plan', 'gana')
            ),
            array(
                'id' => 'header_three_btn_1_url',
                'type' => 'text',
                'title' => esc_html__('btn url', 'gana'),
                'default' => esc_html__('#', 'gana')
            ),
            array(
                'id' => 'header_three_btn_2_text',
                'type' => 'text',
                'title' => esc_html__('Btn 2 Text', 'gana'),
                'default' => esc_html__('Sign Up Free', 'gana')
            ),
            array(
                'id' => 'header_three_nav_2_url',
                'type' => 'text',
                'title' => esc_html__('btn url', 'gana'),
                'default' => esc_html__('#', 'gana')
            ),
        )
    ));

    /* Breadcrumb */
    CSF::createSection($prefix . '_theme_options', array(
        'title' => esc_html__('Breadcrumb', 'gana'),
        'id' => 'breadcrumb_options',
        'icon' => ' eicon-product-breadcrumbs',
        'fields' => array(
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Breadcrumb Options', 'gana') . '</h3>'
            ),
            array(
                'id' => 'breadcrumb_enable',
                'title' => esc_html__('Breadcrumb', 'gana'),
                'type' => 'switcher',
                'desc' => wp_kses(__('you can set <mark>Yes / No</mark> to show/hide breadcrumb', 'gana'), $allowed_html),
                'default' => true,
            ),
            array(
                'id' => 'breadcrumb_bg',
                'title' => esc_html__('Background Image', 'gana'),
                'type' => 'background',
                'desc' => wp_kses(__('you can set <mark>background</mark> for breadcrumb', 'gana'), $allowed_html),
                'default' => array(
                    'background-size' => 'cover',
                    'background-position' => 'center bottom',
                    'background-repeat' => 'no-repeat',
                ),
                'background_color' => false,
                'dependency' => array('breadcrumb_enable', '==', 'true')
            ),
            array(
                'id' => 'breadcrumb_bg_color',
                'title' => esc_html__('Breadcrumb Background Color', 'gana'),
                'type' => 'color',
                'default' => 'rgba(232,0,0, 0.6);',
                'desc' => wp_kses(__('you can set <mark>overlay color</mark> for Breadcrumb background image', 'gana'), $allowed_html),
                'dependency' => array('breadcrumb_enable', '==', 'true')
            ),
        )
    ));


    /*-------------------------------------------------------
           ** Footer  Options
    --------------------------------------------------------*/
    CSF::createSection($prefix . '_theme_options', array(
        'title' => esc_html__('Footer', 'gana'),
        'id' => 'footer_options',
        'icon' => ' eicon-footer',
    ));
    CSF::createSection($prefix . '_theme_options', array(
        'parent' => 'footer_options',
        'id' => 'footer_general_options',
        'title' => esc_html__('Footer One', 'gana'),
        'icon' => 'fa fa-list-ul',
        'fields' => array(
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Footer Settings One', 'gana') . '</h3>'
            ),
            array(
                'id' => 'footer_one_logo',
                'type' => 'media',
                'title' => esc_html__('Logo', 'gana'),
                'library' => 'image',
                'desc' => wp_kses(__('you can upload <mark> logo</mark> here it will overwrite customizer uploaded logo', 'gana'), $allowed_html),
            ),
            array(
                'id' => 'footer_one_info_item',
                'type' => 'switcher',
                'title' => esc_html__('Info Item Button', 'gana'),
                'default' => true,
                'desc' => wp_kses(__('you can <mark> show/hide</mark> info item of header five', 'gana'), $allowed_html),
            ),
            array(
                'id' => 'footer_one_info_item_repeater',
                'type' => 'repeater',
                'title' => esc_html__('Info Item Repeater', 'gana'),
                'dependency' => array('footer_one_info_item', '==', 'true'),
                'fields' => array(
                    array(
                        'id' => 'footer_one_info_item_title',
                        'type' => 'text',
                        'title' => esc_html__('Info  Title', 'gana'),
                        'default' => esc_html__('Call Us Free', 'gana')
                    ),
                    array(
                        'id' => 'footer_one_info_item_number',
                        'type' => 'text',
                        'title' => esc_html__('Info Number', 'gana'),
                        'default' => esc_html__('+91 458 654 528', 'gana')
                    ),
                )
            ),
            array(
                'id' => 'footer_one_social_item',
                'type' => 'switcher',
                'title' => esc_html__('Info Item Button', 'gana'),
                'default' => true,
                'desc' => wp_kses(__('you can <mark> show/hide</mark> info item of header five', 'gana'), $allowed_html),
            ),
            array(
                'id' => 'footer_one_social_item_repeater',
                'type' => 'repeater',
                'title' => esc_html__('Info Item Repeater', 'gana'),
                'dependency' => array('footer_one_social_item', '==', 'true'),
                'fields' => array(
                    array(
                        'id' => 'footer_one_social_item_icon',
                        'type' => 'icon',
                        'title' => esc_html__('Info  Title', 'gana'),
                        'default' => 'fab fa-facebook'
                    ),
                    array(
                        'id' => 'footer_one_social_item_url',
                        'type' => 'text',
                        'title' => esc_html__('Info Number', 'gana'),
                        'default' => esc_html__('#', 'gana')
                    ),
                )
            ),
            array(
                'id' => 'footer_spacing',
                'title' => esc_html__('Footer Spacing', 'gana'),
                'type' => 'switcher',
                'desc' => wp_kses(__('you can set <mark>Yes / No</mark> to set footer spacing', 'gana'), $allowed_html),
                'default' => true,
            ),
            array(
                'id' => 'footer_top_spacing',
                'title' => esc_html__('Footer Top Spacing', 'gana'),
                'type' => 'slider',
                'desc' => wp_kses(__('you can set <mark>padding</mark> for footer top', 'gana'), $allowed_html),
                'min' => 0,
                'max' => 500,
                'step' => 1,
                'unit' => 'px',
                'default' => 100,
                'dependency' => array('footer_spacing', '==', 'true')
            ),
            array(
                'id' => 'footer_bottom_spacing',
                'title' => esc_html__('Footer Bottom Spacing', 'gana'),
                'type' => 'slider',
                'desc' => wp_kses(__('you can set <mark>padding</mark> for footer bottom', 'gana'), $allowed_html),
                'min' => 0,
                'max' => 500,
                'step' => 1,
                'unit' => 'px',
                'default' => 65,
                'dependency' => array('footer_spacing', '==', 'true')
            ),
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Footer Copyright Area Options', 'gana') . '</h3>'
            ),
            array(
                'id' => 'footer_shortcode',
                'type' => 'textarea',
                'title' => esc_html__('Footer Shortcode', 'gana'),
                'shortcoder' => 'gana_shortcodes'
            ),
            array(
                'id' => 'copyright_area_spacing',
                'title' => esc_html__('Copyright Area Spacing', 'gana'),
                'type' => 'switcher',
                'desc' => wp_kses(__('you can set <mark>Yes / No</mark> to set copyright area spacing', 'gana'), $allowed_html),
                'default' => true,
            ),
            array(
                'id' => 'copyright_text',
                'title' => esc_html__('Copyright Area Text', 'gana'),
                'type' => 'textarea',
                'desc' => wp_kses(__('use  <mark>{copy}</mark> for copyright symbol, use <mark>{year}</mark> for current year, ', 'gana'), $allowed_html)
            ),
            array(
                'id' => 'copyright_area_top_spacing',
                'title' => esc_html__('Copyright Area Top Spacing', 'gana'),
                'type' => 'slider',
                'desc' => wp_kses(__('you can set <mark>padding</mark> for copyright area top', 'gana'), $allowed_html),
                'min' => 0,
                'max' => 500,
                'step' => 1,
                'unit' => 'px',
                'default' => 20,
                'dependency' => array('copyright_area_spacing', '==', 'true')
            ),
            array(
                'id' => 'copyright_area_bottom_spacing',
                'title' => esc_html__('Copyright Area Bottom Spacing', 'gana'),
                'type' => 'slider',
                'desc' => wp_kses(__('you can set <mark>padding</mark> for copyright area bottom', 'gana'), $allowed_html),
                'min' => 0,
                'max' => 500,
                'step' => 1,
                'unit' => 'px',
                'default' => 20,
                'dependency' => array('copyright_area_spacing', '==', 'true')
            ),
            array(
                'id' => 'footer_one_bg_image',
                'type' => 'media',
                'title' => esc_html__('Footer One Background Image', 'gana'),
                'library' => 'image',
                'desc' => wp_kses(__('you can upload <mark> background image</mark> here it will overwrite customizer uploaded logo', 'gana'), $allowed_html),
            ),
        )
    ));
    CSF::createSection($prefix . '_theme_options', array(
        'parent' => 'footer_options',
        'id' => 'footer_two_options',
        'title' => esc_html__('Footer Two', 'gana'),
        'icon' => 'fa fa-list-ul',
        'fields' => array(
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Footer Top Settings', 'gana') . '</h3>'
            ),
            array(
                'id' => 'footer_two_shortcode',
                'type' => 'textarea',
                'title' => esc_html__('Footer Shortcode', 'gana'),
                'shortcoder' => 'gana_shortcodes'
            ),
            array(
                'id' => 'footer_bg_image',
                'type' => 'media',
                'title' => esc_html__('Footer Background Image', 'gana'),
                'library' => 'image',
                'desc' => wp_kses(__('you can upload <mark> background image</mark> here it will overwrite customizer uploaded logo', 'gana'), $allowed_html),
            ),
            array(
                'id' => 'footer_animation_image',
                'type' => 'media',
                'title' => esc_html__('Footer Animated Image', 'gana'),
                'library' => 'image',
                'desc' => wp_kses(__('you can upload <mark> animated image</mark> here it will overwrite customizer uploaded logo', 'gana'), $allowed_html),
            ),
            array(
                'id' => 'footer_two_logo',
                'type' => 'media',
                'title' => esc_html__('Logo', 'gana'),
                'library' => 'image',
                'desc' => wp_kses(__('you can upload <mark> logo</mark> here it will overwrite customizer uploaded logo', 'gana'), $allowed_html),
            ),
            array(
                'id' => 'footer_menu_repeater',
                'type' => 'repeater',
                'title' => esc_html__('Footer Menu Repeater', 'gana'),
                'fields' => array(
                    array(
                        'id' => 'footer_menuitem_title',
                        'type' => 'text',
                        'title' => esc_html__('Footer Menu Title', 'gana'),
                        'default' => esc_html__('Home', 'gana'),
                    ),
                    array(
                        'id' => 'footer_menuitem_url',
                        'type' => 'text',
                        'title' => esc_html__('Menu URL', 'gana'),
                        'default' => '#'
                    ),
                )
            ),
            array(
                'id' => 'footer_subscribe',
                'type' => 'text',
                'title' => esc_html__('Footer subscribe', 'gana'),
            ),
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Footer Settings Two', 'gana') . '</h3>'
            ),
            array(
                'id' => 'footer_two_spacing',
                'title' => esc_html__('Footer Spacing', 'gana'),
                'type' => 'switcher',
                'desc' => wp_kses(__('you can set <mark>Yes / No</mark> to set footer spacing', 'gana'), $allowed_html),
                'default' => true,
            ),
            array(
                'id' => 'footer_two_top_spacing',
                'title' => esc_html__('Footer Top Spacing', 'gana'),
                'type' => 'slider',
                'desc' => wp_kses(__('you can set <mark>padding</mark> for footer top', 'gana'), $allowed_html),
                'min' => 0,
                'max' => 500,
                'step' => 1,
                'unit' => 'px',
                'default' => 100,
                'dependency' => array('footer_two_spacing', '==', 'true')
            ),
            array(
                'id' => 'footer_two_bottom_spacing',
                'title' => esc_html__('Footer Bottom Spacing', 'gana'),
                'type' => 'slider',
                'desc' => wp_kses(__('you can set <mark>padding</mark> for footer bottom', 'gana'), $allowed_html),
                'min' => 0,
                'max' => 500,
                'step' => 1,
                'unit' => 'px',
                'default' => 0,
                'dependency' => array('footer_two_spacing', '==', 'true')
            ),
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Footer Copyright Area Options', 'gana') . '</h3>'
            ),
            array(
                'id' => 'copyright_two_area_spacing',
                'title' => esc_html__('Copyright Area Spacing', 'gana'),
                'type' => 'switcher',
                'desc' => wp_kses(__('you can set <mark>Yes / No</mark> to set copyright area spacing', 'gana'), $allowed_html),
                'default' => true,
            ),
            array(
                'id' => 'copyright_text',
                'title' => esc_html__('Copyright Area Text', 'gana'),
                'type' => 'textarea',
                'desc' => wp_kses(__('use  <mark>{copy}</mark> for copyright symbol, use <mark>{year}</mark> for current year, ', 'gana'), $allowed_html)
            ),
            array(
                'id' => 'copyright_two_area_top_spacing',
                'title' => esc_html__('Copyright Area Top Spacing', 'gana'),
                'type' => 'slider',
                'desc' => wp_kses(__('you can set <mark>padding</mark> for copyright area top', 'gana'), $allowed_html),
                'min' => 0,
                'max' => 500,
                'step' => 1,
                'unit' => 'px',
                'default' => 60,
                'dependency' => array('copyright_two_area_spacing', '==', 'true')
            ),
            array(
                'id' => 'copyright_two_area_bottom_spacing',
                'title' => esc_html__('Copyright Area Bottom Spacing', 'gana'),
                'type' => 'slider',
                'desc' => wp_kses(__('you can set <mark>padding</mark> for copyright area bottom', 'gana'), $allowed_html),
                'min' => 0,
                'max' => 500,
                'step' => 1,
                'unit' => 'px',
                'default' => 60,
                'dependency' => array('copyright_two_area_spacing', '==', 'true')
            ),
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Footer About Item Settings', 'gana') . '</h3>'
            ),
            array(
                'id' => 'footer_social_icon',
                'type' => 'switcher',
                'title' => esc_html__('Social Icon', 'gana'),
                'default' => true,
                'desc' => wp_kses(__('you can <mark> show/hide</mark> navbar button of header two', 'gana'), $allowed_html),
            ),
            array(
                'id' => 'footer_social_repeater',
                'type' => 'repeater',
                'title' => esc_html__('Social Item Repeater', 'gana'),
                'dependency' => array('footer_social_icon', '==', 'true'),
                'fields' => array(
                    array(
                        'id' => 'footer_social_icon_item_icon',
                        'type' => 'icon',
                        'title' => esc_html__('Social Item Icon', 'gana'),
                        'default' => 'flaticon-call'
                    ),
                    array(
                        'id' => 'footer_social_icon_item_url',
                        'type' => 'text',
                        'title' => esc_html__('Social URL', 'gana'),
                        'default' => '#'
                    ),
                )
            ),
        )
    ));

    /*-------------------------------------------------------
          ** Blog  Options
    --------------------------------------------------------*/
    CSF::createSection($prefix . '_theme_options', array(
        'id' => 'blog_settings',
        'title' => esc_html__('Blog Settings', 'gana'),
        'icon' => 'fa fa-book'
    ));
    CSF::createSection($prefix . '_theme_options', array(
        'parent' => 'blog_settings',
        'id' => 'blog_post_options',
        'title' => esc_html__('Blog Post', 'gana'),
        'icon' => 'fa fa-list-ul',
        'fields' => Gana_Group_Fields::post_meta('blog_post', esc_html__('Blog Page', 'gana'))
    ));
    CSF::createSection($prefix . '_theme_options', array(
        'parent' => 'blog_settings',
        'id' => 'blog_single_post_options',
        'title' => esc_html__('Single Post', 'gana'),
        'icon' => 'fa fa-list-alt',
        'fields' => Gana_Group_Fields::post_meta('blog_single_post', esc_html__('Blog Single Page', 'gana'))
    ));

    CSF::createSection($prefix . '_theme_options', array(
        'id' => 'shop_settings',
        'title' => esc_html__('Shop Settings', 'gana'),
        'icon' => 'fas fa-shopping-basket',
    ));
    /*  Product page options */
    CSF::createSection($prefix . '_theme_options', array(
        'id' => 'product_shop_page',
        'title' => esc_html__('Product Page', 'gana'),
        'parent' => 'shop_settings',
        'icon' => 'fas fa-shopping-basket',
        'fields' => Gana_Group_Fields::page_layout_options(esc_html__('Product Shop Page', 'gana'), 'product_shop')
    ));
    /*  Product single page options */
    CSF::createSection($prefix . '_theme_options', array(
        'id' => 'product_shop_single_page',
        'title' => esc_html__('Product Single Page', 'gana'),
        'parent' => 'shop_settings',
        'icon' => 'fas fa-shopping-basket',
        'fields' => array(
            array(
                'id' => 'product_shop_single_page_bg_color',
                'type' => 'color',
                'title' => esc_html__('Page Background Color', 'gana'),
                'default' => ''
            ),
            array(
                'id' => 'product_shop_single_page_spacing_top',
                'title' => esc_html__('Page Spacing Top', 'gana'),
                'type' => 'slider',
                'desc' => wp_kses(__('you can set <mark>Padding Top</mark> for page content area.', 'gana'), $allowed_html),
                'min' => 0,
                'max' => 500,
                'step' => 1,
                'unit' => 'px',
                'default' => 120,
            ),
            array(
                'id' => 'product_shop_single_page_spacing_bottom',
                'title' => esc_html__('Page Spacing Bottom', 'gana'),
                'type' => 'slider',
                'desc' => wp_kses(__('you can set <mark>Padding Bottom</mark> for page content area.', 'gana'), $allowed_html),
                'min' => 0,
                'max' => 500,
                'step' => 1,
                'unit' => 'px',
                'default' => 100,
            ),
        ),
    ));

    /*-------------------------------------------------------
          ** Pages & templates Options
   --------------------------------------------------------*/
    CSF::createSection($prefix . '_theme_options', array(
        'id' => 'pages_and_template',
        'title' => esc_html__('Pages Settings', 'gana'),
        'icon' => 'fa fa-files-o'
    ));
    /*  404 page options */
    CSF::createSection($prefix . '_theme_options', array(
        'id' => '404_page',
        'title' => esc_html__('404 Page', 'gana'),
        'parent' => 'pages_and_template',
        'icon' => 'fa fa-exclamation-triangle',
        'fields' => array(
            array(
                'id' => 'error_bg_switch',
                'title' => esc_html__('404 Image Enable', 'gana'),
                'type' => 'switcher',
                'desc' => wp_kses(__('you can set <mark>Yes / No</mark> to show/hide breadcrumb', 'gana'), $allowed_html),
                'default' => true,
            ),
            array(
                'id' => 'error_bg',
                'title' => esc_html__('404 Image', 'gana'),
                'type' => 'media',
                'desc' => wp_kses(__('you can set <mark>background</mark> for breadcrumb', 'gana'), $allowed_html),
                'dependency' => array('error_bg_switch', '==', 'true')
            ),
            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('404 Page Options', 'gana') . '</h3>',
            ),
            array(
                'id' => '404_bg_color',
                'type' => 'color',
                'title' => esc_html__('Page Background Color', 'gana'),
                'default' => ''
            ),
            array(
                'id' => '404_title',
                'title' => esc_html__('Title', 'gana'),
                'type' => 'text',
                'info' => wp_kses(__('you can change <mark>title</mark> of 404 page', 'gana'), $allowed_html),
                'attributes' => array('placeholder' => esc_html__('Sorry! The Page Not Found', 'gana'))
            ),
            array(
                'id' => '404_paragraph',
                'title' => esc_html__('Paragraph', 'gana'),
                'type' => 'textarea',
                'info' => wp_kses(__('you can change <mark>paragraph</mark> of 404 page', 'gana'), $allowed_html),
                'attributes' => array('placeholder' => esc_html__('Oops! The page you are looking for does not exit. it might been moved or deleted.', 'gana'))
            ),
            array(
                'id' => '404_button_text',
                'title' => esc_html__('Button Text', 'gana'),
                'type' => 'text',
                'info' => wp_kses(__('you can change <mark>button text</mark> of 404 page', 'gana'), $allowed_html),
                'attributes' => array('placeholder' => esc_html__('back to home', 'gana'))
            ),
            array(
                'id' => '404_spacing_top',
                'title' => esc_html__('Page Spacing Top', 'gana'),
                'type' => 'slider',
                'desc' => wp_kses(__('you can set <mark>Padding Top</mark> for page content area.', 'gana'), $allowed_html),
                'min' => 0,
                'max' => 500,
                'step' => 1,
                'unit' => 'px',
                'default' => 120,
            ),
            array(
                'id' => '404_spacing_bottom',
                'title' => esc_html__('Page Spacing Bottom', 'gana'),
                'type' => 'slider',
                'desc' => wp_kses(__('you can set <mark>Padding Bottom</mark> for page content area.', 'gana'), $allowed_html),
                'min' => 0,
                'max' => 500,
                'step' => 1,
                'unit' => 'px',
                'default' => 120,
            ),
        )
    ));

    /*  blog page options */
    CSF::createSection($prefix . '_theme_options', array(
        'id' => 'blog_page',
        'title' => esc_html__('Blog Page', 'gana'),
        'parent' => 'pages_and_template',
        'icon' => 'fa fa-indent',
        'fields' => Gana_Group_Fields::page_layout_options(esc_html__('Blog', 'gana'), 'blog')
    ));
    /*  blog single page options */
    CSF::createSection($prefix . '_theme_options', array(
        'id' => 'blog_single_page',
        'title' => esc_html__('Blog Single Page', 'gana'),
        'parent' => 'pages_and_template',
        'icon' => 'fa fa-indent',
        'fields' => Gana_Group_Fields::page_layout_options(esc_html__('Blog Single', 'gana'), 'blog_single')
    ));
    /*  archive page options */
    CSF::createSection($prefix . '_theme_options', array(
        'id' => 'archive_page',
        'title' => esc_html__('Archive Page', 'gana'),
        'parent' => 'pages_and_template',
        'icon' => 'fa fa-archive',
        'fields' => Gana_Group_Fields::page_layout_options(esc_html__('Archive', 'gana'), 'archive')
    ));
    /*  search page options */
    CSF::createSection($prefix . '_theme_options', array(
        'id' => 'search_page',
        'title' => esc_html__('Search Page', 'gana'),
        'parent' => 'pages_and_template',
        'icon' => 'fa fa-search',
        'fields' => Gana_Group_Fields::page_layout_options(esc_html__('Search', 'gana'), 'search')
    ));

    /*-------------------------------------------------------
           ** Backup  Options
    --------------------------------------------------------*/
    CSF::createSection($prefix . '_theme_options', array(
        'id' => 'backup',
        'title' => esc_html__('Import / Export', 'gana'),
        'icon' => 'eicon-export-kit',
        'fields' => array(
            array(
                'type' => 'notice',
                'style' => 'warning',
                'content' => esc_html__('You can save your current options. Download a Backup and Import.', 'gana'),
            ),
            array(
                'type' => 'backup',
                'title' => esc_html__('Backup & Import', 'gana')
            )
        )
    ));
}
